@@ -182,12 +182,10 @@ module Paint
         end
       else
         case ENV['TERM']
-        when /-256color$/, 'xterm'
-          256
         when /-color$/, 'rxvt'
           16
         else # optimistic default
-          256
+          TRUE_COLOR
         end
       end
     end
@@ -226,7 +224,7 @@ module Paint
     end
 
     # Returns best ANSI color matching an RGB value, without fore-/background information
-    # See http://mail.python.org/pipermail/python-list/2008-December/1150496.html
+    # See https://mail.python.org/pipermail/python-list/2008-December/1150496.html
     def rgb_to_ansi(red, green, blue, use_bright = false)
       color_pool =  RGB_COLORS_ANSI.values
       color_pool += RGB_COLORS_ANSI_BRIGHT.values if use_bright
